=======
Credits
=======

Core Developers
---------------

+ John Bloom john.s.bloom@gmail.com
+ Jeffrey DeFond jeff.defond@cleardata.com
+ Adam Sherwood theherk@gmail.com

Contributors
------------

+ David Lee david.lee@cleardata.com
+ Byron Mann byronosity@gmail.com
+ Manoli Yiannakakis manoli.yiannakakis@cleardata.com
